@@ -52,6 +52,15 @@ ev_file_exporter_begin (EvFileExporter        *exporter,
         iface->begin (exporter, fc);
 }
 
+void
+ev_file_exporter_begin_page (EvFileExporter *exporter)
+{
+	EvFileExporterIface *iface = EV_FILE_EXPORTER_GET_IFACE (exporter);
+
+	if (iface->begin_page)
+		iface->begin_page (exporter);
+}
+
 void
 ev_file_exporter_do_page (EvFileExporter  *exporter,
 			  EvRenderContext *rc)
@@ -61,6 +70,15 @@ ev_file_exporter_do_page (EvFileExporter  *exporter,
         iface->do_page (exporter, rc);
 }
 
+void
+ev_file_exporter_end_page (EvFileExporter *exporter)
+{
+	EvFileExporterIface *iface = EV_FILE_EXPORTER_GET_IFACE (exporter);
+	
+	if (iface->end_page)
+		iface->end_page (exporter);
+}
+
 void
 ev_file_exporter_end (EvFileExporter *exporter)
 {
